# Media oEmbed Provider Markup

This module replaces internal Drupal media oEmbed URLs with provider's HTML markup.


Original markup:

```html
<iframe src="https://kelly-d11-2857339.w21.it/media/oembed?url=https%3A//www.youtube.com/watch%3Fv%3Dv9axiNyYDPA&amp;max_width=0&amp;max_height=0&amp;hash=BJhz6k2FYbHUKJh63Nwnj4AtN8IjcSuwda4vqR1FNIk" width="200" height="113" class="media-oembed-content" loading="lazy" title="Biscaya - Vorgetragen auf dem Segelschulschiff &quot;Gorch Fock&quot;"></iframe>
```

Markup with media_oembed_provider_markup:

```html
<iframe width="200" height="113" src="https://www.youtube.com/embed/v9axiNyYDPA?feature=oembed" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" referrerpolicy="strict-origin-when-cross-origin" allowfullscreen="" title="Biscaya - Vorgetragen auf dem Segelschulschiff &quot;Gorch Fock&quot;"></iframe>
```

## Background

oEmbed is a format for allowing an embedded representation of a URL on third party sites. The simple API allows a website to display embedded content (such as photos or videos) when a user posts a link to that resource, without having to parse the resource directly. See https://oembed.com/

oEmbed support inherently introduces potential security hazards -- third-party oEmbed providers can return arbitrary HTML, which may in turn contain executable JavaScript code. Therefore, you should only support oEmbed providers that you trust. Drupal also tries to mitigate the risk of XSS attacks by displaying oEmbed content in an iframe, thus limiting the possible effects of harmful JavaScript. See https://www.drupal.org/node/2966029

To load the embed, Drupal uses an iframe as the media source, the content of which is loaded from /media/oembed. This ensures that the external content is loaded in an iframe.

Due to the changed URL, Consent Manager Platforms (CMPs) do not recognize the external source and cannot block it. This module embeds the original source of the oEmbed provider.

Attention! By embedding the markup of the oEmbed provider, malicious code can be introduced into the website.

## How to use

After downloading and activating the module, the option "Use provider's markup for oEmbed field" can be activated in the display settings of your oEmbed fields.
