<?php

namespace Drupal\Tests\media_oembed_provider_markup\Functional;

use Drupal\Tests\BrowserTestBase;
use Drupal\field\Entity\FieldConfig;
use Drupal\field\Entity\FieldStorageConfig;
use Drupal\media\Entity\Media;
use Drupal\node\Entity\Node;

/**
 * Tests the functionality of media_oembed_provider_markup.
 *
 * @group media_oembed_provider_markup
 */
class OEmbedTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'node',
    'media',
    'media_oembed_provider_markup',
  ];

  /**
   * {@inheritdoc}
   */
  protected $profile = 'standard';

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';
  /**
   * A test user with administrative permissions.
   *
   * @var \Drupal\user\UserInterface
   */
  protected $adminUser;

  /**
   * {@inheritdoc}
   */
  public function setUp(): void {
    parent::setUp();

    // Create user for testing.
    $this->adminUser = $this->drupalCreateUser(
      [
        'view media',
        'access administration pages',
        'administer media',
        'create media',
      ],
      'administrator',
      TRUE
    );

    // Add entity_reference field to node type page.
    $storage = FieldStorageConfig::create([
      'entity_type' => 'node',
      'field_name' => 'field_related_media',
      'type' => 'entity_reference',
      'settings' => [
        'target_type' => 'media',
      ],
    ]);
    $storage->save();

    FieldConfig::create([
      'field_storage' => $storage,
      'entity_type' => 'node',
      'bundle' => 'page',
      'label' => 'Related media',
      'settings' => [
        'handler_settings' => [
          'target_bundles' => [
            'remote_video' => 'remote_video',
          ],
        ],
      ],
    ])->save();

    \Drupal::service('entity_display.repository')->getViewDisplay('node', 'page')
      ->setComponent('field_related_media', [
        'type' => 'entity_reference_entity_view',
        'label' => 'above',
        'settings' => [
          'view_mode' => 'full',
        ],
      ])->save();

  }

  /**
   * Tests enabling of replacing oembed.
   */
  public function testOembedProviderMarkup(): void {
    $this->drupalLogin($this->adminUser);
    // core/modules/media/tests/src/FunctionalJavascript/MediaStandardProfileTest.php
    // Create oembed media.
    $media = Media::create([
      'bundle' => 'remote_video',
      'field_media_oembed_video' => 'https://www.youtube.com/watch?v=v9axiNyYDPA',
      'status' => 1,
    ]);
    $media->save();

    // Create test node.
    $node = Node::create([
      'title' => 'Test node',
      'type' => 'page',
      'field_related_media' => [
        'target_id' => $media->id(),
      ],
    ]);
    $node->save();

    // Get node.
    $this->drupalGet('/node/' . $node->id());

    // Check for oembed url.
    $this->assertSession()
      ->responseContains('/media/oembed?url=https%3A//www.youtube.com/watch%3Fv%3Dv9axiNyYDPA');

    // Change display.
    $viewDisplay = \Drupal::service('entity_display.repository')->getViewDisplay('media', 'remote_video', 'default');
    // $viewDisplay->addDependency('module', 'media_oembed_provider_markup');
    $viewDisplay->setComponent('field_media_oembed_video', [
      'type' => 'oembed',
      'label' => 'hidden',
      'weight' => 0,
      'region' => 'content',
      'third_party_settings' => [
        'media_oembed_provider_markup' => [
          'provider_markup' => 1,
        ],
      ],
    ]);
    $viewDisplay->save();

    // Verify that the markup contains the script tag.
    $this->drupalGet('/node/' . $node->id());

    // Check for original url.
    $this->assertSession()
      ->responseContains('src="https://www.youtube.com/embed/v9axiNyYDPA?feature=oembed"');
  }

}
